#
# spec file for package dahdi-linux
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# needssslcertforbuild


Name:           dahdi-linux
Summary:        Digium Asterisk Hardware Device Interface driver
License:        GPL-2.0
Group:          Productivity/Telephony/Utilities
Version:        2.9.0
Release:        4.4
Url:            http://asterisk.org/

#DL-URL:	http://downloads.asterisk.org/pub/telephony/dahdi-linux/
Source:         http://downloads.asterisk.org/pub/telephony/dahdi-linux/%name-%version.tar.gz
Source2:        http://downloads.asterisk.org/pub/telephony/dahdi-linux/%name-%version.tar.gz.asc
Source3:        %name-preamble
# tarball made from http://downloads.digium.com/pub/telephony/firmware/releases/
Source4:        firmware-20131224.tar.xz
Patch5:         dahdi-pmake.diff
Patch6:         dahdi-moddir.diff
Patch7:         dahdi-kill-xpp_h.diff
Patch8:         dahdi-warn-on-once.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version}
BuildRequires:  fdupes
BuildRequires:  kernel-syms >= 2.6.17
BuildRequires:  modutils
%endif
BuildRequires:  udev
BuildRequires:  xz
%if 0%{?suse_version} >= 1230
BuildRequires:  gpg-offline
%endif
Provides:       dahdi = %version-%release
Obsoletes:      dahdi < %version-%release

# EC2 and UM have no PCI, but DAHDI is all about PCI device drivers
%{?suse_version:%kernel_module_package -p %name-preamble -x ec2 um}

%description
This package contains configuration files, header files, and setup
tools needed for the zapata telephony interface drivers.

See /usr/share/doc/packages/dahdi/README for a list of supported
hardware.

%package KMP
Summary:        Digium Asterisk Hardware Device Interface driver
Group:          System/Kernel

%description KMP
This package contains the kernel modules of the Zapata Telephony
Interface. For details see the dahdi package.

%package devel
Summary:        Development files for the Digium Asterisk Hardware Device Interface
Group:          Development/Libraries/Other
License:	GPL-2.0 and LGPL-2.1
Requires:       %name = %version-%release
Provides:       dahdi-devel = %version-%release
Provides:       dahdi-linux-syms = %version-%release

%description devel
This package contains the header files and libraries necessary for
developing applications which use zaptel.

Install dahdi-devel if you want to develop applications which depend on
asterisk.

%prep
%{?gpg_verify: %gpg_verify %{S:2}}
%setup -qa4
%patch -P 5 -P 6 -P 7 -P 8 -p1
pushd drivers/dahdi/firmware/;
for i in *.tar*; do
	tar -xf "$i";
done;
popd;

# enable echo_oslec for opensuse >11.1 more info regarding oslec is at
# http://www.rowetel.com/blog/?page_id=454
# SUSE already has CONFIG_ECHO=m, so we do not no copy of echo.c.
%if 0%{?suse_version} >= 1120 || 0%{?fedora_version}
perl -i -pe 's{^#(?=obj-m += dahdi_echocan_oslec.o)}{}' drivers/dahdi/Kbuild
%endif

%build
%if !0%{?suse_version}
exit 0
%endif

export CFLAGS="%optflags";
mkdir -p ../obj;
for flavor in %flavors_to_build; do
	cp -a . "../obj/$flavor";
	pushd "../obj/$flavor";
	make KSRC="/usr/src/linux-obj/%_target_cpu/$flavor" %{?_smp_mflags};
	popd;
done;

%install
b="%buildroot";

%if 0%{?suse_version}
for flavor in %flavors_to_build; do
	pushd "../obj/$flavor";
	make INSTALL_MOD_PATH="$b" DESTDIR="$b" \
		KSRC="/usr/src/linux-obj/%_target_cpu/$flavor" \
		%{?_smp_mflags} install;

	# wanpipe-kmp wants this
	dahdi_dir="%_includedir/dahdi/obj/%_target_cpu/$flavor";
	mkdir -p "$b/$dahdi_dir"
	cp -a include "$b/$dahdi_dir/"
	ln -s "%_includedir/dahdi" "$b/$dahdi_dir/include/dahdi";
	mkdir -p "$b/$dahdi_dir/drivers/dahdi";
	cp -a drivers/dahdi/Module*.symvers "$b/$dahdi_dir/drivers/dahdi";

	# wanted by voicesync/wanpipe-voicetime
	cp -a drivers/dahdi/ecdis.h "$b/$dahdi_dir/drivers/dahdi";
	cp -a drivers/dahdi/biquad.h "$b/$dahdi_dir/drivers/dahdi";
	echo "%version" >"$b/$dahdi_dir/.version";

	popd;
done;
%else
make install DESTDIR="$b" install-devices install-include \
	install-firmware install-xpp-firm;
%endif

# remove pointless double copy
rm -Rfv "$b/usr/lib/hotplug"
%if 0%{?fdupes:1}
%fdupes %buildroot/%_prefix
%endif

%files
%defattr(-,root,root)
%doc LICENSE* README
%_datadir/dahdi/
/lib/firmware/*
/lib/firmware/.dahdi*

%files devel
%defattr(-,root,root)
%_includedir/dahdi/

%changelog
* Wed Feb 26 2014 joop.boonen@opensuse.org
- Update to new upstream release 2.9.0
* Fri Dec 27 2013 jengelh@inai.de
- Install all header files
* Tue Dec 24 2013 jengelh@inai.de
- Update to new upstream release 2.8.0.1
  * No upstream changelog was provided
* Thu Oct  3 2013 jengelh@inai.de
- Update to new upstream release 2.7.0.1
  * No upstream changelog was provided
* Thu Aug 15 2013 jengelh@inai.de
- Update to new upstream release 2.7.0
  * Support for Linux 3.10
  * Support for te133, te134, vpmoct032
* Thu Jan 24 2013 jengelh@inai.de
- Add package signature verification
- Kernels older than 2.6.17 are in fact no longer supported, so
  remove SLES10 patch
* Mon Aug 27 2012 jamesp@vicidial.com
- Added extra header files needed by third party drivers to compile
- Added obsoletes for older 'dahdi' packages
* Mon Jun 25 2012 jengelh@inai.de
- Update to new upstream release 2.6.1
  * support for Linux 3.4
  * misc crash and race fixes on unload
* Sun Feb  5 2012 chris@computersalat.de
- update to 2.6.0
  * a lot of changes, please see the ChangeLog file for more info
* Thu Dec 15 2011 jengelh@medozas.de
- Update to new upstream release 2.6.0-rc1, changelog is at
  http://downloads.asterisk.org/pub/telephony/dahdi-linux/ChangeLog-2.6.0-rc1
* Mon Oct 31 2011 jengelh@medozas.de
- Ship Module.symvers for use by "wanpipe" package
* Mon Oct 17 2011 jengelh@medozas.de
- Add patch to add missing WARN_ON_ONCE define to wctdm24xxp for
  kernels < 2.6.18
* Tue Oct  4 2011 jengelh@medozas.de
- Update to new upstream release 2.5.0.1, for changelog see
  http://downloads.asterisk.org/pub/telephony/dahdi-linux/ChangeLog-2.5.0.1
- Update to firmware-20111005 (2.5.0.1 depends on it),
  and reduce its size by removing redundant files in the archive.
- Remove redundant/unwanted tags/sections (cf. specfile guidelines)
- Remove duplicate copy of firmware files
- Put building commands into %%build, not %%install;
  replace convoluted installation by single-shot installation
- Enable parallel make
- Build for all kernel flavors
- Exclude EC2 flavor due to lack of PCI which DAHDI requires
- Set the minimum kernel version required (currently: 2.6.18-rc1
  due to use of WARN_ON_ONCE in source code)
- Add Provides: dahdi/dahdi-devel to cater for BuildRequires of
  other packages
- Avoid compiling echo.ko again, allows to drop kernel-source
- dahdi-linux should not require KMP (gives "have choice"), rather,
  KMPs should Require dahdi-linux (for firmware)
* Tue Apr 12 2011 chris@computersalat.de
- update to 2.4.1.2
  * include/dahdi/kernel.h: dahdi: Do not define dev_name if already
    backported. RHEL 5.6 has backported dev_name in
    include/dahdi/devices.h. We now need to check for a back ported
    definition before defining our own version on pre 2.6.26 kernels.
    (closes issue #18992) Reported by: ndupeux, AlexCeli Tested by:
    elguero Signed-off-by: Tzafrir Cohen <tzafrir.cohen@xorcom.com>
    Acked-by: Shaun Ruffell <sruffell@digium.com> Origin:
    http://svnview.digium.com/svn/dahdi?view=rev&rev=9894
  * wctdm24xxp: Fix regression with LEDS on TDM410.
- remove Author from Description
* Tue Mar  8 2011 chris@computersalat.de
- update to 2.4.1
  * build_tools/make_version: make_version: Use 'git rev-parse' if
    only looking for a sha5. Different versions of git have
    variability in how the log output looks. Instead of git log, we
    can use git rev-parse directly. Signed-off-by: Shaun Ruffell
    <sruffell@digium.com> Origin:
    http://svnview.digium.com/svn/dahdi?view=rev&rev=9475
  * build_tools/make_version: make_version: svn and git metadata
    directory not checked properly. (closes issue #16143) Reported
    by: Max Khon Signed-off-by: Kinsey Moore <kmoore@digium.com>
    Signed-off-by: Shaun Ruffell <sruffell@digium.com> Origin:
    http://svnview.digium.com/svn/dahdi?view=rev&rev=9418
  * build_tools/make_version: make_version: '[[' -> '[' since it's
    not a bash script. '[[' is a bash construct specifically, yet
    [#]!/bin/sh is at the top of the file. Signed-off-by: Shaun Ruffell
    <sruffell@digium.com> Acked-by: Kinsey Moore <kmoore@digium.com>
    Acked-by: Russ Meyerriecks <rmeyerriecks@digium.com> Acked-by:
    Tzafrir Cohen <tzafrir.cohen@xorcom.com> Review:
    https://reviewboard.asterisk.org/r/940/ Origin:
    http://svnview.digium.com/svn/dahdi?view=rev&rev=9408
  * Makefile, build_tools/make_version: dahdi: Generate
    include/dahdi/version.h when building in a git repository. If
    building within a git repository search the last log message for
    a 'git-svn-id'. If found, the commit has a corresponding svn
    revision number and we will use the SVN-xxx-rxxx revision form.
    Otherwise use the output of 'git describe --long --always --tags
  - -dirty=M' as the version. Signed-off-by: Shaun Ruffell
    <sruffell@digium.com> Acked-by: Tzafrir Cohen
    <tzafrir.cohen@xorcom.com> Origin:
    http://svnview.digium.com/svn/dahdi?view=rev&rev=9396
  - for further changes please see ChangeLog file
* Sat Nov  6 2010 chris@computersalat.de
- spec cleanup
  o macros
* Fri Nov  5 2010 toganm@opensuse.org
- enable echo_oslec for opensuse >11.1 more info regarding oslec is at
  http://www.rowetel.com/blog/?page_id=454
* Thu Nov  4 2010 chris@computersalat.de
- update to 2.4.0
  o lot of changes please see ChangeLog file
- reworked firmware
  o added dahdi-fwload-vpmadt032-1.25.0.tar.gz
* Wed Jun 16 2010 chris@computersalat.de
- fix build for Factory (11.3)
- removed obsolete patches
  o dahdi, rtc, kzalloc
* Tue Jun 15 2010 chris@computersalat.de
- update to 2.3.0.1
  * drivers/dahdi/voicebus/GpakCust.h, /,
    drivers/dahdi/voicebus/GpakApi.c,
    drivers/dahdi/voicebus/voicebus.c,
    drivers/dahdi/voicebus/GpakCust.c: Merged revisions
    8560,8575-8576 via svnmerge from
    https://origsvn.digium.com/svn/dahdi/linux/trunk ........ r8560 |
    sruffell | 2010-04-22 16:36:16 -0500 (Thu, 22 Apr 2010) | 11
    lines wcte12xp, wctdm24xxp: Ensure writes to I/O registers are
    flushed. In revision 8176 I changed register access from I/O
    space to memory mapped registers. Unfortunately, when I made that
    change, I didn't account for posted writes. This change makes
    sure all the registers are read back to ensure that they are
    posted through any intermediate bridges. The most readily
    observable symptom were cards that were taking 2000
    interrupts/second. The card reported that it handled an interrupt
    but the write to silence the card wasn't flushed through until
    the second time the interrupt handler run. DAHDI-602. ........
    r8575 | sruffell | 2010-04-26 18:29:16 -0500 (Mon, 26 Apr 2010) |
    4 lines wcte12xp, wctdm24xxp: Do not allow interruptible sleep on
    VPM lock. If the sleep is ever interrupted, 'up' will still be
    called in the GpakApi, essentially making the lock useless after
    that point. ........ r8576 | sruffell | 2010-04-26 18:29:17 -0500
    (Mon, 26 Apr 2010) | 9 lines wcte12xp, wctdm24xxp: Retry if the
    VPMADT032 reports not ready. CheckDspReset can return -1 if the
    DSP is not ready to process any new commands. In this case we
    should retry a few times to give the DSP a chance to become
    ready. While I'm not ready to say this definitely fixes recently
    reported cases when the wcte12xp driver constantly resets, it
    eliminated communication failures to the DSP module when under
    stress (via the vpm_firmware_version sysfs attribute). However, I
    haven't let it run long enough to say that the issue is resolved.
    DAHDI-603. ........
  * /, drivers/dahdi/dahdi_echocan_jpah.c: missing #include: fixes
    building with 2.6.34-rc5 With kernel 2.6.34-rc5 an explicit
    '#include <slab.h>' is required for using kzalloc() and friends.
    Merged revisions 8550 via svnmerge from
    http://svn.digium.com/svn/dahdi/linux/trunk
  * drivers/dahdi/xpp/xpp_debug, /, drivers/dahdi/xpp/card_pri.c,
    drivers/dahdi/wcb4xxp/Makefile, drivers/dahdi/xpp/card_bri.c,
    drivers/dahdi/xpp/card_global.c, drivers/dahdi/dahdi-base.c:
    typos, mostly unkown Merged revisions 8539 via svnmerge from
    http://svn.digium.com/svn/dahdi/linux/trunk
  * Makefile, /: Remove generation of kernel-doc API docs It's not
    really useful, and it breaks building 'docs' without a kernel
    tree. Merged revisions 8538 via svnmerge from
    http://svn.digium.com/svn/dahdi/linux/trunk
  * /: initialize svnmerge
* Thu Apr 22 2010 chris@computersalat.de
- fix build for kernel > 2.6.34
  o added kzalloc patch
* Wed Apr 21 2010 chris@computersalat.de
- update to 2.3.0
  * lot of changes see ChangeLog
- updated firmware
- remove obsolete patches
  * dahdi-linux-2.2.1.1-autoconf_h.patch
  * dahdi-driver.patch
* Sat Mar 27 2010 chris@computersalat.de
- update to 2.2.1.1
  * wct4xxp: Added support for for qfalc v3.1 framer.
  * wct4xxp: Added ID tags for generation 5 firmware updates
- added autoconf.h patch
  o fix build for kernel > 2.6.31
    autoconf.h moved from linux/ to generated
- rpmlint
  o fixed group for devel pkg Development/Libraries/Other
- clenup spec
* Fri Jan 22 2010 chris@computersalat.de
- update to 2.2.1
  * dahdi-linux version 2.2.1 released.
  * drivers/dahdi/xpp/xbus-pcm.c, /: xpp: demote a message that
    generates some false alarms. Merged revisions 7843 via svnmerge
    from http://svn.digium.com/svn/dahdi/linux/trunk
  * /, drivers/dahdi/xpp/firmwares/USB_FW.hex: xpp: USB_FW rev 7578
    Fixes various minor twinstar-related bugs. Merged revisions 7815
    via svnmerge from http://svn.digium.com/svn/dahdi/linux/trunk
  * drivers/dahdi/xpp/xbus-pcm.c, /: xpp: fixes for drift
    calculation. Should help for the case of multiple quad-PRI
    Astribanks on a single system. xpp rev: 7666. Merged revisions
    7807 via svnmerge from
    http://svn.digium.com/svn/dahdi/linux/trunk
  * drivers/dahdi/xpp/xbus-pcm.c, /, drivers/dahdi/xpp/xbus-pcm.h,
    drivers/dahdi/xpp/xbus-sysfs.c: xpp: Improved inter-Astribank
    drift calculation. Merged revisions 7625 via svnmerge from
    http://svn.digium.com/svn/dahdi/linux/trunk
  * drivers/dahdi/dahdi-base.c: dahdi-base: change
    dahdi_kernel_fpu_end to kernel_fpu_end dahdi_kernel_fpu_end is
    part of the MMX changes in trunk that was not committed into the
    2.2 branch. This change snuck in as part of revision 6864 with
    the master span processing changes.
  * voicebus, wcte12xp: Only define SLAB_STORE_USER when CONFIG_SLUB
    is defined. On 2.6.22, there is was a bug in the SLUB allocator
    that required defining SLAB_STORE_USER, however this setting is
    only valid when CONFIG_SLUB is defined and not when using the
    previous slab allocator. DAHDI-424.
- added ChangeLog, LICENSE*, README to doc
* Thu Jan 14 2010 chris@computersalat.de
- include actual tarball version in package version
- cleanup source
  o updated tarball to its upstream version
  * it is an rc release
* Sat Jan  9 2010 chris@computersalat.de
- fix build-/deps
- moved changelog to changes file
- removed pre/-un post/-un
* Mon Jan  4 2010 chris@computersalat.de
- cleanup spec
  o added header
  o sort TAGS
  o fix deps
  o some rpmlint stuff
- cleanup source
  o added .changes file
- kernel modules to "updates"
* Mon Dec 21 2009 vittorio@vitsoft.bz
- dahdi-linux 2.2.1
* Wed Aug 19 2009 vittorio@vitsoft.bz
- dahdi-linux 2.2.0.2
* Fri Jul  3 2009 vittorio@vitsoft.bz
- dahdi-linux 2.2.0.1
* Wed Jul  1 2009 vittorio@vitsoft.bz
- dahdi-linux 2.2.0
* Wed Dec 10 2008 vittorio@vitsoft.bz
- dahdi-linux 2.1.0
* Sat Oct  4 2008 vittorio@vitsoft.bz
- dahdi-linux 2.0.0
* Mon Sep 15 2008 vittorio@vitsoft.bz
- dahdi-linux 2.0.0 rc4
